Crate farm_analyze_lo

Crate farm_analyze_lo 

Modules

accompanyings
Constracts of accompanying. Be careful that there are some variations about one combatant.

Structs

Detail
A dataclass of simulated result. The each value is floored.
HeadCount
The counter for unit members. the number must be between 2 and 5.
Stage
dataclass for stage to farm.
UnitIO
Details for unit io. this does’nt have some special logics. It’s data class.
UnitIOMaker
The builder for out of res and in of exp.

Enums

Chicks
it is cover if there is chick who has leader-buff and improved-learning-system. So others are uncover. Add, it has average of total-resource.

Functions

simulate